CREATE OR REPLACE PROCEDURE WSO2_CONFIRMATION_CODE_CLEANUP_SP IS 

    i INT := 0;
    chunk_size INT := 5000;
    number_of_rows INT := 0;
    
BEGIN

    SELECT COUNT(*) INTO number_of_rows from ALL_TABLES where table_name = upper('TEMP_REG_RESOURCE_INVALID_ID');
    IF (number_of_rows = 1) then
    EXECUTE IMMEDIATE 'DROP TABLE TEMP_REG_RESOURCE_INVALID_ID';
    COMMIT;
    END if;
    
    EXECUTE IMMEDIATE 'CREATE TABLE TEMP_REG_RESOURCE_INVALID_ID (REG_PROPERTY_ID INTEGER)';
    COMMIT;
    
    EXECUTE IMMEDIATE 'INSERT INTO TEMP_REG_RESOURCE_INVALID_ID (REG_PROPERTY_ID)
    SELECT REG_PROPERTY_ID
    FROM REG_RESOURCE_PROPERTY
    WHERE REG_PROPERTY_ID NOT IN ( 
        SELECT REG_PROPERTY_ID FROM REG_RESOURCE_PROPERTY 
        INNER JOIN REG_RESOURCE 
        ON REG_RESOURCE_PROPERTY.REG_PATH_ID = REG_RESOURCE.REG_PATH_ID
        UNION 
        SELECT REG_PROPERTY_ID FROM REG_RESOURCE_PROPERTY 
        INNER JOIN REG_RESOURCE  
        ON REG_RESOURCE_PROPERTY.REG_VERSION = REG_RESOURCE.REG_VERSION
    )';
    COMMIT;

    EXECUTE IMMEDIATE 'SELECT COUNT(*) FROM TEMP_REG_RESOURCE_INVALID_ID' INTO number_of_rows;
    WHILE (i <= number_of_rows/chunk_size) LOOP  					
        EXECUTE IMMEDIATE 'DELETE 
        FROM REG_RESOURCE_PROPERTY 
        WHERE REG_PROPERTY_ID 
        IN (
            SELECT REG_RESOURCE_PROPERTY.REG_PROPERTY_ID 
            FROM REG_RESOURCE_PROPERTY 
            INNER JOIN TEMP_REG_RESOURCE_INVALID_ID 
            ON REG_RESOURCE_PROPERTY.REG_PROPERTY_ID = TEMP_REG_RESOURCE_INVALID_ID.REG_PROPERTY_ID
            FETCH FIRST '||chunk_size||' ROWS ONLY
        )';
        COMMIT;	
                
        DBMS_LOCK.sleep(2);
        
        EXECUTE IMMEDIATE 'DELETE 
        FROM REG_PROPERTY 
        WHERE REG_ID 
        IN (
            SELECT REG_PROPERTY.REG_ID 
            FROM REG_PROPERTY 
            INNER JOIN TEMP_REG_RESOURCE_INVALID_ID 
            ON REG_PROPERTY.REG_ID = TEMP_REG_RESOURCE_INVALID_ID.REG_PROPERTY_ID
            FETCH FIRST '||chunk_size||' ROWS ONLY
        )';
        COMMIT;	
        
        i := i + 1;
        DBMS_LOCK.sleep(2);
    END LOOP; 

    EXECUTE IMMEDIATE 'DROP TABLE TEMP_REG_RESOURCE_INVALID_ID';
    COMMIT;
END;
